PasswordRule class

Constructors

PasswordRule({required String description, required bool validator(String password), Widget? passedWidget, Widget? failedWidget, Color passedColor = const Color(0xFF4CAF50), Color failedColor = const Color(0xFF9E9E9E), int? minLength, int? maxLength, String? disallowedSymbols})

Properties

description String
final
disallowedSymbols String?
final
failedColor Color
final
failedWidget Widget?
final
hashCode int
The hash code for this object.
no setterinherited
maxLength int?
final
minLength int?
final
passedColor Color
final
passedWidget Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator bool Function(String password)
final

Methods

copyWith({Widget? passedWidget, Widget? failedWidget, Color? passedColor, Color? failedColor, int? minLength, int? maxLength, String? disallowedSymbols}) PasswordRule
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited