PasswordValidation class

Inheritance

Constructors

PasswordValidation({Key? key, required String password, List<PasswordRule>? rules, Widget itemBuilder(bool isPassed, String description)?, TextStyle descriptionStyle = const TextStyle(color: Colors.grey), Widget? divider, Widget? passWidget, Widget? failedWidget, Color? passColor, Color? failedColor, Color? passDescriptionColor, Color? failedDescriptionColor, void onValidationChanged(bool allPassed, Map<String, bool> results)?})
const

Properties

descriptionStyle TextStyle
final
divider Widget?
final
failedColor Color?
final
failedDescriptionColor Color?
final
failedWidget Widget?
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(bool isPassed, String description)?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onValidationChanged → void Function(bool allPassed, Map<String, bool> results)?
final
passColor Color?
final
passDescriptionColor Color?
final
passWidget Widget?
final
password String
final
rules List<PasswordRule>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited