PasswordValidators class

Constructors

PasswordValidators()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

caseSensitiveInfo() PasswordRule
defaultRules() List<PasswordRule>
hasLowerCase({String? descriptionForLowerCase}) PasswordRule
hasNumber({String? descriptionForNumber}) PasswordRule
hasUpperCase({String? descriptionForUpperCase}) PasswordRule
minMaxLength({int min = 8, int? max}) PasswordRule
noSpacesOrSymbols({String disallowed = r".,\-|/=_"}) PasswordRule